==> segatex-5.40.tgz: segatex-5.40/src/main.cpp <==
/*
 * segatex_editor SELinux tool.
 *
 * Copyright (C) 2007-2008 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qapplication.h>
#include <qsplashscreen.h>
#include <qtextcodec.h>

#include "mainwindow.h"

int main(int argc, char *argv[])
{
    
	QApplication app(argc, argv);
	QTranslator appTranslator;
	//appTranslator.load(QString("app_") + QTextCodec::locale(),
	//			qApp->applicationDirPath());
	appTranslator.load(QString("segatex_") + QTextCodec::locale(),
				"/root/segatex");
	//appTranslator.load("segatex_jp",
	//			"/root/segatex");
	app.installTranslator(&appTranslator);
	QSplashScreen *splash = new QSplashScreen(QPixmap::fromMimeSource("/root/segatex/splash.png"));
	splash->show();
	splash->message(QObject::tr("Setting up the main window..."),
			Qt::AlignRight | Qt::AlignTop, Qt::white);
	//QApplication app(argc, argv);
	MainWindow mainWin;
	app.setMainWidget(&mainWin);

	if (argc > 1) {
		for (int i = 1; i < argc; ++i){
		    mainWin.openFile(argv[i]);
		}
	} else {
		mainWin.newFile();
	}

	mainWin.show();
	return app.exec();
}

==> segatex-6.80.tgz: segatex-6.80/src/main.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2008 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qapplication.h>
#include <qsplashscreen.h>
#include <qtextcodec.h>
//testing for daemon
#include <stdlib.h>

#include "mainwindow.h"

int main(int argc, char *argv[])
{
	QApplication app(argc, argv);
	QTranslator appTranslator;
	appTranslator.load(QString("segatex_") + QTextCodec::locale(),
				"/root/segatex");
	app.installTranslator(&appTranslator);
	QSplashScreen *splash = new QSplashScreen(QPixmap::fromMimeSource("/root/segatex/splash.png"));
	splash->show();
	splash->message(QObject::tr("Setting up the main window..."),
			Qt::AlignRight | Qt::AlignTop, Qt::white);
	//QApplication app(argc, argv);
	MainWindow mainWin;
	app.setMainWidget(&mainWin);

	if (argc > 1) {
		for (int i = 1; i < argc; ++i){
		    mainWin.openFile(argv[i]);
		}
	} else {
		mainWin.newFile();
	}

	mainWin.show();
	return app.exec();
}
